summaryrefslogtreecommitdiff
path: root/src/viewport.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/viewport.cpp')
-rw-r--r--src/viewport.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/viewport.cpp b/src/viewport.cpp
index ef78356c4..3fcc45125 100644
--- a/src/viewport.cpp
+++ b/src/viewport.cpp
@@ -1407,9 +1407,9 @@ static void ViewportDrawStrings(DrawPixelInfo *dpi, const StringSpriteToDrawVect
/* if we didn't draw a rectangle, or if transparant building is on,
* draw the text in the colour the rectangle would have */
if (IsTransparencySet(TO_SIGNS) && ss->string != STR_WHITE_SIGN) {
/* Real colours need the IS_PALETTE_COLOUR flag
* otherwise colours from _string_colourmap are assumed. */
- colour = (TextColour)_colour_gradient[ss->colour][6] | IS_PALETTE_COLOUR;
+ colour = (TextColour)_colour_gradient[ss->colour][6] | TC_IS_PALETTE_COLOUR;
}
/* Draw the rectangle if 'tranparent station signs' is off,
@@ -1407,9 +1407,9 @@ static void ViewportDrawStrings(DrawPixelInfo *dpi, const StringSpriteToDrawVect
* draw the text in the colour the rectangle would have */
if (IsTransparencySet(TO_SIGNS) && ss->string != STR_WHITE_SIGN) {
- /* Real colours need the IS_PALETTE_COLOUR flag
+ /* Real colours need the TC_IS_PALETTE_COLOUR flag
* otherwise colours from _string_colourmap are assumed. */